summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorgspencer@chromium.org <gspencer@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-10-12 08:04:12 +0000
committergspencer@chromium.org <gspencer@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-10-12 08:04:12 +0000
commit644a041c9dd21ce8f0399d2913fdd1f12272e42c (patch)
tree3629809c3f09f6061817bbc9af313d078c10d012
parent64e12c532860dbed554250602f779e4b16eb8edd (diff)
downloadchromium_src-644a041c9dd21ce8f0399d2913fdd1f12272e42c.zip
chromium_src-644a041c9dd21ce8f0399d2913fdd1f12272e42c.tar.gz
chromium_src-644a041c9dd21ce8f0399d2913fdd1f12272e42c.tar.bz2
This makes it so we only add the default plugin if it's enabled.
BUG=none TEST=ran test_shell_tests on linux Review URL: http://codereview.chromium.org/3707005 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@62265 0039d316-1c4b-4281-b951-d872f2087c98
-rw-r--r--webkit/glue/plugins/plugin_list.cc5
1 files changed, 3 insertions, 2 deletions
diff --git a/webkit/glue/plugins/plugin_list.cc b/webkit/glue/plugins/plugin_list.cc
index 30e74b1..e2aeed1 100644
--- a/webkit/glue/plugins/plugin_list.cc
+++ b/webkit/glue/plugins/plugin_list.cc
@@ -430,8 +430,9 @@ void PluginList::GetPluginInfoArray(const GURL& url,
}
}
- // Add the default plugin at the end if it supports the mime type given.
- if (!plugins_.empty()) {
+ // Add the default plugin at the end if it supports the mime type given,
+ // and the default plugin is enabled.
+ if (!plugins_.empty() && webkit_glue::IsDefaultPluginEnabled()) {
const WebPluginInfo& default_info = plugins_.back();
DCHECK(default_info.path.value() == kDefaultPluginLibraryName);
if (SupportsType(default_info, mime_type, allow_wildcard)) {